[![Build Status](https://travis-ci.com/GMLC-TDC/utilities.svg?branch=master)](https://travis-ci.com/GMLC-TDC/utilities)
[![Build Status](https://dev.azure.com/phlptp/utilities/_apis/build/status/GMLC-TDC.utilities?branchName=master)](https://dev.azure.com/phlptp/utilities/_build/latest?definitionId=2&branchName=master)
[![codecov](https://codecov.io/gh/GMLC-TDC/utilities/branch/master/graph/badge.svg)](https://codecov.io/gh/GMLC-TDC/utilities)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/357c0c3dfea243079af3e3a8faedea57)](https://www.codacy.com/app/GMLC-TDC/utilities?utm_source=github.com&utm_medium=referral&utm_content=GMLC-TDC/utilities&utm_campaign=Badge_Grade)
[![](https://img.shields.io/badge/License-BSD-blue.svg)](https://github.com/GMLC-TDC/utilities/blob/master/LICENSE)

# Utilities

Collection of utilities used inside [HELICS](https://github.com/GMLC-TDC/HELICS) and supporting repos. These utilities are used for data storage for different purposes inside the code. In some cases they were made more general than needed to support other types or be useful elsewhere.

## General utilities

### StringOps

A collection of common operations on StringOps

### StringView_ops

similar to stringOps but on string_view objects

## Release

The Utilities library is distributed under the terms of the BSD-3 clause license. All new
contributions must be made under this license. [LICENSE](LICENSE)

SPDX-License-Identifier: BSD-3-Clause
